==> zio-aws-ec2_2.12-5.20.17.2-sources.jar: zio/aws/ec2/model/ModifyInstanceEventWindowResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyInstanceEventWindowResponse(
    instanceEventWindow: Optional[zio.aws.ec2.model.InstanceEventWindow] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse = {
    import ModifyInstanceEventWindowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
      .builder()
      .optionallyWith(instanceEventWindow.map(value => value.buildAwsValue()))(
        _.instanceEventWindow
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyInstanceEventWindowResponse.ReadOnly =
    zio.aws.ec2.model.ModifyInstanceEventWindowResponse.wrap(buildAwsValue())
}
object ModifyInstanceEventWindowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyInstanceEventWindowResponse =
      zio.aws.ec2.model.ModifyInstanceEventWindowResponse(
        instanceEventWindow.map(value => value.asEditable)
      )
    def instanceEventWindow
        : Optional[zio.aws.ec2.model.InstanceEventWindow.ReadOnly]
    def getInstanceEventWindow
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceEventWindow.ReadOnly] =
      AwsError.unwrapOptionField("instanceEventWindow", instanceEventWindow)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
  ) extends zio.aws.ec2.model.ModifyInstanceEventWindowResponse.ReadOnly {
    override val instanceEventWindow
        : Optional[zio.aws.ec2.model.InstanceEventWindow.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceEventWindow())
        .map(value => zio.aws.ec2.model.InstanceEventWindow.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
  ): zio.aws.ec2.model.ModifyInstanceEventWindowResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.104.13-sources.jar: zio/aws/ec2/model/ModifyInstanceEventWindowResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyInstanceEventWindowResponse(
    instanceEventWindow: Option[zio.aws.ec2.model.InstanceEventWindow] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse = {
    import ModifyInstanceEventWindowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
      .builder()
      .optionallyWith(instanceEventWindow.map(value => value.buildAwsValue()))(
        _.instanceEventWindow
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ModifyInstanceEventWindowResponse.ReadOnly =
    zio.aws.ec2.model.ModifyInstanceEventWindowResponse.wrap(buildAwsValue())
}
object ModifyInstanceEventWindowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyInstanceEventWindowResponse =
      zio.aws.ec2.model.ModifyInstanceEventWindowResponse(
        instanceEventWindow.map(value => value.asEditable)
      )
    def instanceEventWindow
        : Option[zio.aws.ec2.model.InstanceEventWindow.ReadOnly]
    def getInstanceEventWindow
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceEventWindow.ReadOnly] =
      AwsError.unwrapOptionField("instanceEventWindow", instanceEventWindow)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
  ) extends zio.aws.ec2.model.ModifyInstanceEventWindowResponse.ReadOnly {
    override val instanceEventWindow
        : Option[zio.aws.ec2.model.InstanceEventWindow.ReadOnly] = scala
      .Option(impl.instanceEventWindow())
      .map(value => zio.aws.ec2.model.InstanceEventWindow.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceEventWindowResponse
  ): zio.aws.ec2.model.ModifyInstanceEventWindowResponse.ReadOnly = new Wrapper(
    impl
  )
}
